@@ -516,7 +516,7 @@ def event_notif_tree_callback(session, notif_type, notif, timestamp, priv):
         python object.
 
     :returns:
-        User error code (sr_error_t).
+        None
     :raises:
         IMPORTANT: This function *CANNOT* raise any exception. The C callstack does not
         handle that well and when it happens the outcome is undetermined. Make sure to
@@ -543,12 +543,18 @@ def event_notif_tree_callback(session, notif_type, notif, timestamp, priv):
                 ).values()
             )
         )
-        callback(xpath, notif_type, notif_dict, timestamp, private_data)
+        if is_async_func(callback):
+            task = subscription.loop.create_task(
+                callback(xpath, notif_type, notif_dict, timestamp, private_data)
+            )
+            task.add_done_callback(
+                functools.partial(subscription.task_done, None, "notif")
+            )
+        else:
+            callback(xpath, notif_type, notif_dict, timestamp, private_data)
 
-    except BaseException as e:
+    except BaseException:
         # ATTENTION: catch all exceptions!
         # including KeyboardInterrupt, CancelledError, etc.
         # We are in a C callback, we cannot let any error pass
         LOG.exception("%r callback failed", locals().get("callback", priv))
-        if isinstance(session, SysrepoSession) and isinstance(xpath, str):
-            session.set_error(xpath, str(e))
